<?php

namespace MoAzureObjectSync\API;

class Azure{

    private static $obj;
    private $endpoints;
    private $config;
    private $scope = "https://graph.microsoft.com/.default";
    private $access_token;
    private $handler;

    private function __construct($config){
        $this->config = $config;
        $this->handler = Authorization::getController();
    }

    public static function getClient($config){
        if(!isset(self::$obj)){
            self::$obj = new Azure($config);
            self::$obj->setEndpoints();
        }
        return self::$obj;
    }

    public function mo_azos_sync_azure_users(){
        $this->access_token = sanitize_text_field($this->handler->mo_azos_get_access_token_using_client_credentials($this->endpoints,$this->config,$this->scope));
        if(!$this->access_token){
            wp_die(esc_html("Access token is missing from the response. Please try again later."));
        }
        $this->fetch_users_using_access_token();
    }

    private function setEndpoints(){
        $this->endpoints['authorize'] = 'https://login.microsoftonline.com/'.$this->config['tenant_id'].'/oauth2/v2.0/authorize';
        $this->endpoints['token'] = 'https://login.microsoftonline.com/'.$this->config['tenant_id'].'/oauth2/v2.0/token';
        $this->endpoints['users'] = 'https://graph.microsoft.com/beta/users/';
    }

    private function fetch_users_using_access_token(){
        $args = [
            'Authorization' => 'Bearer '.$this->access_token
        ];
        $users = $this->handler->mo_azos_get_request($this->endpoints['users'],$args);
        if(!is_array($users) || count($users)<=0){
            wp_die(esc_html("Unknown error occurred. Please try again later."));
        }
        foreach ($users['value'] as $user){
            if(!empty($user)){
                $user_login = sanitize_user($user['id']);
                $user_email = sanitize_email($user['userPrincipalName']);
                $user_id = username_exists($user_login);
                if(!$user_id){
                    $user_id = email_exists($user_email);
                }
                if(!$user_id){
                    $random_pass = wp_generate_password('12', false);
                    $user_id = wp_create_user($user_login, $random_pass, $user_email);
                }else{
                    wp_update_user([
                        'user_email' => $user_email
                    ]);
                }
            }
        }
    }

    public function mo_azos_get_specific_user_detail(){
        $this->access_token = $this->handler->mo_azos_get_access_token_using_client_credentials($this->endpoints,$this->config,$this->scope);
        $args = [
            'Authorization' => 'Bearer '.$this->access_token
        ];
        $user_info_url = $this->endpoints['users'].$this->config['upn_id'];
        $users = $this->handler->mo_azos_get_request($user_info_url,$args);
        if(!is_array($users) || count($users)<=0){
            wp_die(esc_html("Unknown error occurred. Please try again later."));
        }
        return $users;
    }
}