<?php

namespace MoAzureObjectSync\Controller;

use MoAzureObjectSync\API\Azure;
use MoAzureObjectSync\Wrappers\wpWrapper;

class appConfig{

    private static $instance;

    public static function getController(){
        if(!isset(self::$instance)){
            $class = __CLASS__;
            self::$instance = new $class;
        }
        return self::$instance;
    }

    public function mo_azos_save_settings(){
        $option = sanitize_text_field($_POST['option']);
        switch ($option){
            case 'mo_azos_client_config_option':{
                $this->mo_azos_save_client_config();
                break;
            }
            case 'mo_azos_client_sync_users_option':{
                $this->mo_azos_sync_users();
                break;
            }
        }
    }

    private function mo_azos_check_for_empty_or_null(&$input,$arr){
        foreach ($arr as $key){
            if(!isset($_POST[$key]) || empty($_POST[$key])){
                return false;
            }
            $input[$key] = sanitize_text_field($_POST[$key]);
        }
        return $input;
    }

    private function mo_azos_save_client_config(){
        check_admin_referer('mo_azos_client_config_option');
        $input_arr = ['client_id','client_secret','redirect_uri','tenant_id'];
        $sanitized_arr = [];
        if(!$this->mo_azos_check_for_empty_or_null($sanitized_arr,$input_arr)){
            wpWrapper::mo_azos__show_error_notice(esc_html__("Input is empty or present in the incorrect format."));
            return;
        }
        $sanitized_arr['upn_id'] = isset($_POST['upn_id'])?sanitize_text_field($_POST['upn_id']):'';
        $sanitized_arr['client_secret'] = wpWrapper::mo_azos_encrypt_data($sanitized_arr['client_secret'],hash("sha256",$sanitized_arr['client_id']));
        wpWrapper::mo_azos_set_option("mo_azos_application_config",$sanitized_arr);
        wpWrapper::mo_azos__show_success_notice(esc_html__("Settings Saved Successfully."));
    }

    private function mo_azos_sync_users(){
        check_admin_referer('mo_azos_client_sync_users_option');
        $data = wpWrapper::mo_azos_get_option('mo_azos_application_config');
        if(!$data || empty($data)){
            return;
        }
        $azure_client = Azure::getClient($data);
        $azure_client->mo_azos_sync_azure_users();
        wpWrapper::mo_azos__show_success_notice(esc_html__("Users synced successfully."));
    }
}