<?php

/*
Plugin Name: User Sync for Azure AD Office365
Plugin URI: https://plugins.miniorange.com/
Description: This plugin will allow you to sync users from Azure AD / Azure B2C / Office 365 to wordpress.
Version: 1.0.2
Author: miniOrange
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/

namespace MoAzureObjectSync;
require_once __DIR__ . '/vendor/autoload.php';

use MoAzureObjectSync\View\adminView;
use MoAzureObjectSync\Controller\adminController;
use MoAzureObjectSync\Observer\adminObserver;
use MoAzureObjectSync\View\feedbackForm;

define('MO_AZOS_PLUGIN_FILE',__FILE__);
define('MO_AZOS_PLUGIN_DIR',__DIR__.DIRECTORY_SEPARATOR);

class MOAZOS{

    private static $instance;

    public static function mo_azos_load_instance(){
        if(!isset(self::$instance)){
            $class = __CLASS__;
            self::$instance = new $class;
            self::$instance->mo_azos_load_hooks();
        }
        return self::$instance;
    }

    public function mo_azos_load_hooks(){
        add_action('admin_menu',[$this,'mo_azos_admin_menu']);
        add_action( 'admin_enqueue_scripts', [$this, 'mo_azos_settings_style' ] );
        add_action( 'admin_enqueue_scripts', array( $this, 'mo_azos_settings_script' ) );
        add_action('admin_init',[adminController::getController(),'mo_azos_admin_controller']);
        add_action('init',[adminObserver::getObserver(),'mo_azos_admin_observer']);
        add_action( 'admin_footer', [feedbackForm::getView() , 'mo_azos_display_feedback_form'] );
        register_uninstall_hook(__FILE__, 'mo_azos_uninstall');
    }

    public function mo_azos_admin_menu(){
        $page = add_menu_page(
            'WP Azure Object Sync Settings ' .__('API Configuration'),
            'Azure/Office365 User Sync',
            'administrator',
            'mo_azos',
            [adminView::getView(),'mo_azos_menu_display'],
            plugin_dir_url( __FILE__ ) . 'images/miniorange.png'
        );
    }

    function mo_azos_settings_style($page){
        if( $page != 'toplevel_page_mo_azos'){
            return;
        }
        $css_url = plugins_url('includes/css/mo_azos_settings.css',__FILE__);
        $css_phone_url = plugins_url('includes/css/phone.css',__FILE__);
        $css_date_time_url = plugins_url('includes/css/datetime-style-settings.css',__FILE__);
        $css_jquery_ui_url = plugins_url('includes/css/jquery-ui.css',__FILE__);
        
        wp_enqueue_style('mo_azos_css',$css_url,array());
        wp_enqueue_style('mo_azos_phone_css',$css_phone_url,array());
        wp_enqueue_style('mo_azos_date_time_css',$css_date_time_url,array());
        wp_enqueue_style('mo_azos_jquery_ui_css',$css_jquery_ui_url,array());
    }

    function mo_azos_settings_script($page){
        if( $page != 'toplevel_page_mo_azos'){
            return;
        }
        $phone_js_url = plugins_url('includes/js/phone.js',__FILE__);
        $timepicker_js_url = plugins_url('includes/js/timepicker.min.js',__FILE__);
        $select2_js_url = plugins_url('includes/js/select2.min.js',__FILE__);

        wp_enqueue_script('jquery-ui-datepicker'); 
        wp_enqueue_script('mo_azos_phone_js',$phone_js_url,array());
        wp_enqueue_script('mo_azos_timepicker_js',$timepicker_js_url,array());
        wp_enqueue_script('mo_azos_select2_js',$select2_js_url,array());
    }

}
MOAZOS::mo_azos_load_instance();